package com.ruoyi.business.test.service;

import java.util.List;
import com.ruoyi.business.test.domain.TestStudentsScores;

/**
 * 学生成绩Service接口
 * 
 * @author Duke_yzl
 * @date 2025-02-18
 */
public interface ITestStudentsScoresService 
{
    /**
     * 查询学生成绩
     * 
     * @param scoreId 学生成绩主键
     * @return 学生成绩
     */
    public TestStudentsScores selectTestStudentsScoresByScoreId(Long scoreId);

    /**
     * 查询学生成绩列表
     * 
     * @param testStudentsScores 学生成绩
     * @return 学生成绩集合
     */
    public List<TestStudentsScores> selectTestStudentsScoresList(TestStudentsScores testStudentsScores);

    /**
     * 新增学生成绩
     * 
     * @param testStudentsScores 学生成绩
     * @return 结果
     */
    public boolean insertTestStudentsScores(TestStudentsScores testStudentsScores);

    /**
     * 修改学生成绩
     * 
     * @param testStudentsScores 学生成绩
     * @return 结果
     */
    public boolean updateTestStudentsScores(TestStudentsScores testStudentsScores);

    /**
     * 批量删除学生成绩
     * 
     * @param scoreIds 需要删除的学生成绩主键集合
     * @return 结果
     */
    public boolean deleteTestStudentsScoresByScoreIds(Long[] scoreIds);

    /**
     * 删除学生成绩信息
     * 
     * @param scoreId 学生成绩主键
     * @return 结果
     */
    public boolean deleteTestStudentsScoresByScoreId(Long scoreId);
}
